@@ -4,9 +4,9 @@ function(long1, lat1, long2, lat2, long3, lat3) {
   if (((long1-long3)^2-(lat1-lat3))==32400) warning('site 1 and 3 are exactly opposite one another, and so the triangle is undefined')
   if (((long2-long3)^2-(lat2-lat3))==32400) warning('site 2 and 3 are exactly opposite one another, and so the triangle is undefined')
   R <- 40041.47/(2*pi)
-  cx <- deg.dist(lat1,long1,lat2,long2)/R
-  bx <- deg.dist(lat1,long1,lat3,long3)/R
-  ax <- deg.dist(lat2,long2,lat3,long3)/R
+  cx <- deg.dist(long1,lat1,long2,lat2)/R
+  bx <- deg.dist(long1,lat1,long3,lat3)/R
+  ax <- deg.dist(long2,lat2,long3,lat3)/R
   A <- acos((cos(ax)-cos(bx)*cos(cx))/(sin(bx)*sin(cx)))
   B <- acos((cos(bx)-cos(cx)*cos(ax))/(sin(cx)*sin(ax)))
   C <- acos((cos(cx)-cos(ax)*cos(bx))/(sin(ax)*sin(bx)))
